## dbt-bigquery 1.10.0-b1 - April 28, 2025

### Features

- Allow copy_partitions in microbatch ([#1414](https://github.com/dbt-labs/dbt-adapters/issues/1414))
- Add authentication method for Workload Identity Federation. ([#593](https://github.com/dbt-labs/dbt-adapters/issues/593))
- Add support for creating BigQuery labels from meta configuration ([#889](https://github.com/dbt-labs/dbt-adapters/issues/889))
- Support bigframes in dbt bigquery python model ([#921](https://github.com/dbt-labs/dbt-adapters/issues/921))
- Support timeout in bigframes mode of dbt python model ([#949](https://github.com/dbt-labs/dbt-adapters/issues/949))
- Support custom packages in bigframes mode ([#978](https://github.com/dbt-labs/dbt-adapters/issues/978))
- Support oauth secrets credential method in bigframes mode ([#1026](https://github.com/dbt-labs/dbt-adapters/issues/1026))

### Fixes

- Fix issue where dbt-bigquery was not retrying in certain retryable scenarios, e.g. 503's ([#682](https://github.com/dbt-labs/dbt-adapters/issues/682))
- Cast `event_time` to a timestamp prior to comparing against microbatch start/end time ([#1422](https://github.com/dbt-labs/dbt-adapters/issues/1422))
- Fix issue where rate limit errors on table service calls are not retried ([#1423](https://github.com/dbt-labs/dbt-adapters/issues/1423))
- Fix retry scenarios so that dbt always retries when BigQuery recommends a retry ([#263](https://github.com/dbt-labs/dbt-adapters/issues/263))
- Fix silently ignoring materialized view authorization ([#1471](https://github.com/dbt-labs/dbt-adapters/issues/1471))
- Format the outputs of notebook execution ([#943](https://github.com/dbt-labs/dbt-adapters/issues/943))
- Create a new default runtime template ([#950](https://github.com/dbt-labs/dbt-adapters/issues/950))
- use compute_region instead of dataproc_region ([#957](https://github.com/dbt-labs/dbt-adapters/issues/957))
- Fix the credential method issue ([#970](https://github.com/dbt-labs/dbt-adapters/issues/970))
- Raise an error when notebook execution failed ([#976](https://github.com/dbt-labs/dbt-adapters/issues/976))
- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))
- Make location optional in bigframes ([#1001](https://github.com/dbt-labs/dbt-adapters/issues/1001))
- Quick fix of session in table.sql ([#1003](https://github.com/dbt-labs/dbt-adapters/issues/1003))
- set job_timeout_ms in job config so BQ cancels queries on timeout ([#1004](https://github.com/dbt-labs/dbt-adapters/issues/1004))

### Under the Hood

- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#1407](https://github.com/dbt-labs/dbt-adapters/issues/1407))
- replace DbtRuntime exception with DbtDatabase exception in dbt-bigquery connection exception handling ([#798](https://github.com/dbt-labs/dbt-adapters/issues/798))
- Added annotation for recording. ([#761](https://github.com/dbt-labs/dbt-adapters/issues/761))

### Dependencies

- Permits newer versions of google-cloud-storage than 2.4.x to be used, defaults to latest ([#931](https://github.com/dbt-labs/dbt-adapters/pull/931))

### Contributors
- [@borjavb](https://github.com/borjavb) ([#1414](https://github.com/dbt-labs/dbt-adapters/issues/1414))
- [@brabster](https://github.com/brabster) ([#931](https://github.com/dbt-labs/dbt-adapters/pull/931))
- [@jenniferjsmmiller](https://github.com/jenniferjsmmiller) ([#593](https://github.com/dbt-labs/dbt-adapters/issues/593))
- [@jialuoo](https://github.com/jialuoo) ([#921](https://github.com/dbt-labs/dbt-adapters/issues/921), [#949](https://github.com/dbt-labs/dbt-adapters/issues/949), [#978](https://github.com/dbt-labs/dbt-adapters/issues/978), [#1026](https://github.com/dbt-labs/dbt-adapters/issues/1026), [#943](https://github.com/dbt-labs/dbt-adapters/issues/943), [#950](https://github.com/dbt-labs/dbt-adapters/issues/950), [#957](https://github.com/dbt-labs/dbt-adapters/issues/957), [#970](https://github.com/dbt-labs/dbt-adapters/issues/970), [#976](https://github.com/dbt-labs/dbt-adapters/issues/976), [#1001](https://github.com/dbt-labs/dbt-adapters/issues/1001), [#1003](https://github.com/dbt-labs/dbt-adapters/issues/1003))
- [@kubikb](https://github.com/kubikb) ([#1471](https://github.com/dbt-labs/dbt-adapters/issues/1471))
- [@physcat](https://github.com/physcat) ([#889](https://github.com/dbt-labs/dbt-adapters/issues/889))
